Builder

Struct Builder 

pub struct Builder {
    pub aliases: HashMap<String, SrcRef>,
    pub rules: HashMap<String, RuleBuild>,
    pub imports: Vec<SrcRef>,
    pub entry_type: String,
}

Fields

aliases: HashMap<String, SrcRef>rules: HashMap<String, RuleBuild>imports: Vec<SrcRef>entry_type: String

Implementations

Source

impl Builder

pub fn new(entry_type: String) -> Self

pub fn get_program_instructions(ast: &Gramem) -> &Vec<Gramem>

pub fn process(&mut self, ast: &Gramem, src: &str)

pub fn set_sub_aliases( &self, base: &ProductionBuild, productions: &mut RuleBuild, src: &str, )

Sets the aliases for each production as a optional item alias, except for the ones defined in base. Also, adds a None alias for the productions that doesn’t have a alias defined in another.

pub fn dump_grammar(&self, src: &str) -> String

Returns an expressions that returns a RuleMap

Panics

Never.

pub fn write_rule(out: &mut String, name: &str, prods: &RuleBuild, src: &str)

Writes the rule production

Panics

Never.

pub fn dump_reductor(&self, src: &str) -> String

Dumps an expression that returns a ReductMap

Panics

Never.

pub fn write_rule_reduction( out: &mut String, entry_type: &str, name: &str, prods: &RuleBuild, src: &str, )